@@ -58,10 +58,10 @@ class CouchdbkitHandler(object):
         for app_name, app_setting in databases.iteritems():
             uri = app_setting['URL']
 
-            # Blank credentials are valid for the admin party
-            user = app_setting.get('USER', '')
-            password = app_setting.get('PASSWORD', '')
-            auth = BasicAuth(user, password)
+            # Do not send credentials when they are both None as admin party will give a 401
+            user = app_setting.get('USER')
+            password = app_setting.get('PASSWORD')
+            filters = [BasicAuth(user, password)] if (user or password) is not None else []
 
             try:
                 if isinstance(uri, (list, tuple)):
@@ -75,7 +75,7 @@ class CouchdbkitHandler(object):
                 raise ValueError("couchdb uri [%s:%s] invalid" % (
                     app_name, uri))
 
-            res = CouchdbResource(server_uri, timeout=COUCHDB_TIMEOUT, filters=[auth])
+            res = CouchdbResource(server_uri, timeout=COUCHDB_TIMEOUT, filters=filters)
 
             server = Server(server_uri, resource_instance=res)
             app_label = app_name.split('.')[-1]
@@ -137,8 +137,16 @@ class CouchdbkitHandler(object):
         This is used to reduce the waiting time for blocking view updates """
 
         app_name = app.__name__.rsplit('.', 1)[0]
-        app_label = app_name.split('.')[-1]
-        if app_label in self._databases:
+        app_labels = set()
+        schema_list = self.app_schema.values()
+        for schema_dict in schema_list:
+            for schema in schema_dict.values():
+                app_module = schema.__module__.rsplit(".", 1)[0]
+                if app_module == app_name and not schema._meta.app_label in app_labels:
+                    app_labels.add(schema._meta.app_label)
+        for app_label in app_labels:
+            if not app_label in self._databases:
+                continue
             if verbosity >=1:
                 print "Copy prepared design docs for `%s`" % app_name
             db = self.get_db(app_label)
